<?php
/**
 * kimmia functions and definitions
 *
 * @since kimmia 1.0
 */
 
 
/**
 * All kimmia common functions.
 * Don't remove it.
 *
 * @since kimmia 1.0
 */
require_once("inc/kimmia-functions.php");
require_once("inc/penguin/penguin-functions.php");


/**
 * Sets up theme custom options, post, update notifier.
 * Don't remove it.
 *
 * @since kimmia 1.0
 */
include_once("inc/penguin-config.php");
require_once("inc/tools/sidebar_generator.php");
require_once('inc/plugins-config.php');

/**
 * Get all kimmia options value
 */
global $kimmia_options,$penguin_options;
$kimmia_options 	=	get_option("kimmia_options");
$penguin_options	=	$kimmia_options;

// Generate Options CSS
add_action('admin_init', 'kimmia_generate_options_css');

add_action('wp_ajax_nopriv_post-like', 'kimmia_post_like');
add_action('wp_ajax_post-like', 'kimmia_post_like');
add_filter('manage_portfolio_posts_columns', 'kimmia_posts_column_views');
add_action('manage_portfolio_posts_custom_column', 'kimmia_posts_custom_column_views', 5, 2);

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ){
	$content_width = 940;
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links and post formats.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since kimmia 1.0
 */
function kimmia_setup() {

	// Load the Themes' Translations through domain
	load_theme_textdomain( 'kimmia', get_template_directory() . '/languages' );
	
	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );
	
	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'kimmia_menu', __( 'Kimmia Menus', 'kimmia' ) );
	register_nav_menu( 'kimmia_bottom_menu', __( 'Kimmia Bottom Menus', 'kimmia' ) );

	// Add support for a variety of post formats
	add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio' ,'image' , 'quote' ) );
	
	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be the size of the header image that we just defined
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( 770, 999, false );
	
	//columns image size
	penguin_add_image_size( 'two-column-thumbs' , 570 , 999 , false);
	penguin_add_image_size( 'three-column-thumbs' , 370 , 999 , false);
	penguin_add_image_size( 'four-column-thumbs' , 270 , 999 , false);
}
add_action( 'after_setup_theme', 'kimmia_setup' );

/**
 * Sets up theme defaults styles and scripts.
 *
 * @since kimmia 1.0
 */
function kimmia_init_styles_scripts() {
	global $google_load_fonts,$kimmia_options;
	
	//get template directory url
	$dir = get_template_directory_uri();
	
	//get theme version
	$theme_data = wp_get_theme();
	$ver = $theme_data['Version'];
	
	//Stylesheets
	
	/* bootstrap & fontawesome css files */
	wp_enqueue_style( 'bootstrap', $dir . '/bootstrap/css/bootstrap.min.css' , array() , $ver );
	wp_enqueue_style( 'fontawesome', $dir . '/fontawesome/css/font-awesome.min.css' , array() , $ver );
	
	wp_enqueue_style( 'flexslider_style', $dir . '/js/flexslider/flexslider.css' , array() , $ver );
	wp_enqueue_style( 'fancyBox_style', $dir . '/js/fancyBox/jquery.fancybox.css' , array() , $ver );
	wp_enqueue_style( 'fancyBox_helper_style', $dir . '/js/fancyBox/helpers/jquery.fancybox-thumbs.css' , array() , $ver );

	wp_enqueue_style( 'kimmia_style', get_stylesheet_uri()  , array() , $ver );
	
	wp_enqueue_style( 'bootstrap_responsive', $dir . '/bootstrap/css/bootstrap-responsive.min.css' , array() , $ver );
	wp_enqueue_style( 'kimmia_responsive', $dir . '/css/responsive.css' , array() , $ver );
	
	//Custom
	kimmia_get_custom_font();
	$kimmia_options_update = get_option('kimmia_options_update');
	if(isset($kimmia_options_update['version'])){
		if(is_multisite()) {
			$uploads = wp_upload_dir();
			wp_enqueue_style('custom-styles', $uploads['baseurl'] . '/custom-styles.css', array() , $kimmia_options_update['version']);
		} else {
			wp_enqueue_style('custom-styles', $dir . '/custom/custom-styles.css' , array() , $kimmia_options_update['version'] );
		}
	}
	
	//Font
	if($google_load_fonts != null && $google_load_fonts != ""){
		$subsets = penguin_get_options_key('google-font-subset') != "" ? '&subset='.penguin_get_options_key('google-font-subset') : "";
		wp_enqueue_style( 'custom-font', 'http://fonts.googleapis.com/css?family='.$google_load_fonts.$subsets);
	}
	
	//Javascripts
	wp_enqueue_script('jquery');
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_script( 'bootstrap' , $dir . '/bootstrap/js/bootstrap.min.js' , array('jquery') , $ver , true);
	wp_enqueue_script( 'isotope' , $dir . '/js/jquery.isotope.min.js' , array('jquery') , $ver , true);
	wp_enqueue_script( 'fancyBox_mousewheel' , $dir . '/js/fancyBox/jquery.mousewheel-3.0.6.pack.js' , array('jquery') , $ver , true);
	wp_enqueue_script( 'fancyBox_js' , $dir . '/js/fancyBox/jquery.fancybox.pack.js' , array('jquery') , $ver , true);
	wp_enqueue_script( 'fancyBox_helpers_js' , $dir . '/js/fancyBox/helpers/jquery.fancybox-thumbs.js' , array('jquery') , $ver , true);
	wp_enqueue_script( 'flexslider_js' , $dir . '/js/flexslider/jquery.flexslider-min.js' , array('jquery') , $ver , true);
	wp_enqueue_script( 'like_post' , $dir . '/js/jquery.likepost.js' , array('jquery') , $ver , true);
	wp_enqueue_script( 'kimmia' , $dir . '/js/jquery.theme.js' , array('jquery') , $ver , true);
	
	wp_localize_script('like_post', 'ajax_var', array(
		'url' => admin_url('admin-ajax.php'),
		'nonce' => wp_create_nonce('ajax-nonce')
	));

}
add_action('wp_enqueue_scripts', 'kimmia_init_styles_scripts');

/**
 * Sets up custom theme styles
 *
 * @since kimmia 1.0
 */
function kimmia_custom_styles(){
	global $kimmia_options;
	
	kimmia_get_page_custom_options_css();

	if(penguin_get_options_key('custom-enable-css') == "on" && penguin_get_options_key('custom-css-content') != ""){
		?>
<style id="kimmia-custom-css" type="text/css">
	<?php echo $kimmia_options['custom-css-content']; ?>
	
	@media only screen and (-Webkit-min-device-pixel-ratio: 1.5),
	only screen and (-moz-min-device-pixel-ratio: 1.5),
	only screen and (-o-min-device-pixel-ratio: 3/2),
	only screen and (min-device-pixel-ratio: 1.5) {
	<?php echo $kimmia_options['custom-css-retina-content']; ?>
	}
</style>
        <?php 
	}
	
	if(intval(penguin_get_options_key('google_analytics-position')) == 0){
		echo penguin_get_options_key('google_analytics-text');
	}
	
}
add_action( 'wp_head', 'kimmia_custom_styles' );

/**
 * Sets up custom title
 *
 * @since kimmia 1.0
 */
function kimmia_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'twentythirteen' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'kimmia_wp_title', 10, 2 );

/**
 * Sets up footer custom theme styles
 *
 * @since kimmia 1.0
 */
function kimmia_wp_footer_scripts(){
	global $kimmia_options;
	//get template directory url
	$dir = get_template_directory_uri();

	/* google map */
	wp_enqueue_script( 'googleapis', 'http://maps.googleapis.com/maps/api/js?v=3&amp;sensor=false');
	wp_enqueue_script( 'map-infobox', $dir . '/js/infobox.js');
	
	if(penguin_get_options_key('custom-enable-scripts') == "on" && penguin_get_options_key('custom-scripts-content') != ""){?>
<script type="text/javascript">
<?php echo $kimmia_options['custom-scripts-content']; ?>
</script>
<?php }
	if( intval(penguin_get_options_key('google_analytics-position')) == 1 ) {
		echo penguin_get_options_key('google_analytics-text');
	}
}
add_action( 'wp_footer', 'kimmia_wp_footer_scripts' );

/**
 * Add shortcode
 *
 * @since kimmia 1.0
 */
 
// Use shortcodes in text widgets.
add_filter('widget_text', 'do_shortcode');
include("inc/shortcodes.php");

/**
 * Register our sidebars and widgetized areas. Also register the default Epherma widget.
 *
 * @since kimmia 1.0
 */
function kimmia_widgets_init() {
	
		register_sidebar( array(
		'name' => __( 'Global Sidebar', 'kimmia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4><div class="line"><span class="left-line"></span><span class="right-line"></span></div><div class="clear"></div>'
	));
	
	register_sidebar( array(
		'id'	=>'sidebar-footer-1',
		'name' => __( 'Footer 1', 'kimmia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4><div class="clear"></div>'
	));
	
	register_sidebar( array(
		'id'	=>'sidebar-footer-2',
		'name' => __( 'Footer 2', 'kimmia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4><div class="clear"></div>'
	));
	
	register_sidebar( array(
		'id'	=>'sidebar-footer-3',
		'name' => __( 'Footer 3', 'kimmia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4><div class="clear"></div>'
	));
	
	register_sidebar( array(
		'id'	=>'sidebar-footer-4',
		'name' => __( 'Footer 4', 'kimmia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4><div class="clear"></div>'
	));
}
add_action( 'widgets_init', 'kimmia_widgets_init' );
include_once("inc/custom-widgets.php");

/**
 * Get footer widget items columns
 */
function kimmia_get_footer_widget_active_items(){
	$count = 0;
	$cols = 12;
	if (function_exists('dynamic_sidebar')){
		if(is_active_sidebar('sidebar-footer-1')){ $count++;}
		if(is_active_sidebar('sidebar-footer-2')){ $count++;}
		if(is_active_sidebar('sidebar-footer-3')){ $count++;}
		if(is_active_sidebar('sidebar-footer-4')){ $count++;}
		if($count == 0) return 'span12';
		$cols = 12/$count;
	}
	return 'span'.$cols;
}

/**
 * Redesign login page
 */
function kimmia_login_logo() { 
	global $kimmia_options;
?>
    <style type="text/css">
		body.login {background: #e0e0e0;}
        body.login div#login h1 a {
			background: url(<?php echo penguin_get_options_key('logo-image') == "" ?  get_template_directory_uri()."/images/logo.png" : $kimmia_options['logo-image']; ?>) no-repeat top center;
        }
    </style>
<?php }
add_action( 'login_enqueue_scripts', 'kimmia_login_logo' );

function kimmia_login_logo_url() {
    return home_url();
}
add_filter( 'login_headerurl', 'kimmia_login_logo_url' );

function kimmia_login_logo_url_title() {
    return get_bloginfo('title');
}
add_filter( 'login_headertitle', 'kimmia_login_logo_url_title' );

?>